"use strict";
/*---------------------------------------------------------------------------------------------
 *  Copyright (c) Microsoft Corporation. All rights reserved.
 *  Licensed under the MIT License. See License.txt in the project root for license information.
 *--------------------------------------------------------------------------------------------*/
Object.defineProperty(exports, "__esModule", { value: true });
const vscode = require("vscode");
const tableOfContentsProvider_1 = require("../tableOfContentsProvider");
class MarkdownFoldingProvider {
    constructor(engine) {
        this.engine = engine;
    }
    async provideFoldingRanges(document, _token) {
        const tocProvider = new tableOfContentsProvider_1.TableOfContentsProvider(this.engine, document);
        const toc = await tocProvider.getToc();
        const foldingRanges = toc.map((entry, startIndex) => {
            const start = entry.line;
            let end = undefined;
            for (let i = startIndex + 1; i < toc.length; ++i) {
                if (toc[i].level <= entry.level) {
                    end = toc[i].line - 1;
                    break;
                }
            }
            return new vscode.FoldingRange(start, typeof end === 'number' ? end : document.lineCount - 1);
        });
        return new vscode.FoldingRangeList(foldingRanges);
    }
}
exports.default = MarkdownFoldingProvider;

//# sourceMappingURL=https://ticino.blob.core.windows.net/sourcemaps/206928db3cd5b76a80847d55ec5c5abb9e3c0ac0/extensions\markdown\out/features\foldingProvider.js.map
